@@ -48,7 +48,7 @@ module NumRu
         nary /= (ndiv-1)
         return UNumeric.new(nary, units), ndiv
       else
-        nary.div!(ndiv-1)
+        nary = nary.div!(ndiv-1)
         vary = VArray.new(nary,
                           {"long_name"=>"covariance","units"=>units.to_s},
                           "covariance")
@@ -57,7 +57,7 @@ module NumRu
       end
     end
 
-    def corelation(gphys0, gphys1, *dims)
+    def correlation(gphys0, gphys1, *dims)
       val0 = gphys0.val
       val1 = gphys1.val
       if val0.is_a?(NArrayMiss)
@@ -80,9 +80,9 @@ module NumRu
       gphys1 = gphys1.copy.replace_val(val1)
 
       covariance, ndiv = gphys0.covariance(gphys1,*dims)
+      dims = dims.map{|dim| gphys0.dim_index(dim) }
       return covariance/(gphys0.stddev(*dims)*gphys1.stddev(*dims)), mask.to_type(NArray::LINT).sum(*dims)
     end
-    alias correlation corelation
   end
 
   class GPhys
@@ -90,10 +90,9 @@ module NumRu
       GAnalysis.covariance(self, other, *dims)
     end
 
-    def corelation(other, *dims)
-      GAnalysis.corelation(self, other, *dims)
+    def correlation(other, *dims)
+      GAnalysis.correlation(self, other, *dims)
     end
-    alias correlation corelation
   end
 end
 
