@@ -92,7 +92,7 @@ module NumRu
         end
         w /= w.mean
         w.reshape!(n)
-      else
+      elsif new_grid.rank >= 2
         nc0 = new_grid.coord(0)
         nc1 = new_grid.coord(1)
         if !(opts[:disable_weight]||opts["disable_weight"]) &&
@@ -107,6 +107,8 @@ module NumRu
         else
           w = nil
         end
+      else
+        w = nil
       end
 
       ary = NArrayMiss.new(gphys.typecode, n_lost, n)
