@@ -215,14 +215,16 @@ module NumRu
       #   number of functions (also unsolvable).
       # 
       def least_square_fit(data, grid_locs, functions, ensemble_dims=nil,
-                           indep_dims=nil)
+                           indep_dims=nil, with_offset=true)
 
         #< argument check >
 
         grid_locs.each_with_index{|x,i| self.ensure_1D_NArray(x, i)}
         functions.each{|f| raise("Found non-Proc arg") if !f.is_a?(Proc)}
 
-        functions = functions + [@@unity]   # constanf offset
+        if with_offset
+          functions = functions + [@@unity]   # constanf offset
+        end
 
         ng = grid_locs.length
         rank = data.rank
@@ -336,9 +338,16 @@ module NumRu
           c = na
 
           # best fit
-          bf = c[-1]    # the constant offset
-          for i in 0...ms-1
-            bf += c[i]*fv[i]
+          if with_offset
+            bf = c[-1]    # the constant offset
+            for i in 0...ms-1
+              bf += c[i]*fv[i]
+            end
+          else
+            bf = 0.0
+            for i in 0...ms
+              bf += c[i]*fv[i]
+            end
           end
 
         else    # fitting multiple times
@@ -381,9 +390,16 @@ module NumRu
             end
           end
           cs = c.reshape(ms, *idshp_full)
-          bf = cs[-1,false]
-          for i in 0...ms-1
-            bf += cs[i,false]*fv[i]
+          if with_offset
+            bf = cs[-1,false]
+            for i in 0...ms-1
+              bf += cs[i,false]*fv[i]
+            end
+          else
+            bf = cs[-1,false] * 0
+            for i in 0...ms
+              bf += cs[i,false]*fv[i]
+            end
           end
 
         end
