@@ -442,8 +442,9 @@ module NumRu
 
       # geopotential height -> geostrophic winds
       def gph2ug_vg(gph)
-        psi, gpref = gph2psi_gpref(gph)
-        psi2ug_vg(psi)
+        gpx, gpy = Planet::grad_s(gph * Met::g)
+        f = f_mask0(gph)
+        [ -gpy/f, gpx/f]
       end
 
       # geopotential height -> QG stream function and the reference geopotential
@@ -627,8 +628,9 @@ module NumRu
 
       # geopotential height -> geostrophic winds
       def gph2ug_vg(gph)
-        gpd, gpref = gph2gpd_gpref(gph)
-        gpd2ug_vg(gpd)
+        gpx, gpy = Planet::grad_s(gph * Met::g)
+        f = f_mask0(gph)
+        [ -gpy/f, gpx/f]
       end
 
       #########
