@@ -1,5 +1,6 @@
 require "numru/netcdf.rb"
 require "numru/gphys/attribute.rb"
+require "numru/gphys/netcdf_convention"
 
 =begin
 =class Attribute_NetCDF
@@ -12,6 +13,8 @@ module NumRu
       def initialize( ncvar )
 	 raise TypeError unless NetCDFVar===ncvar || NetCDF===ncvar
 	 @nv = ncvar
+	 convention = NetCDF_Conventions.find(ncvar.file)
+	 extend( convention::Attribute_Mixin )
       end
 
       def [](name)
