@@ -1210,7 +1210,8 @@ module NumRu
         grid = Grid.new(*axes)
         if gp0.assoc_coords
           assoc_coords = gp0.assoccoordnames.collect do |aname|
-            GPhys.join( gpnary.collect{|gp| gp.assoc_coord_gphys(aname)}, true )
+            GPhys.join( gpnary.collect{|gp| gp.assoc_coord_gphys(aname)}, true,
+                        true )
           end
           grid.set_assoc_coords(assoc_coords)
         end
@@ -1222,7 +1223,7 @@ module NumRu
         GPhys.new(grid, data)
       end
 
-      def GPhys.join_md(gpnary)
+      def GPhys.join_md(gpnary, no_sort=false)
         #< Check >
 
         if !gpnary.is_a?(NArray)
@@ -1283,7 +1284,7 @@ module NumRu
         end
 
         #< Sort along dimensions to join >
-        gpnary = __sort_gpnary(gpnary)
+        gpnary = __sort_gpnary(gpnary) unless no_sort
 
         #< Join! >
         self.join_md_nocheck(gpnary)
@@ -1294,7 +1295,7 @@ module NumRu
       # ARGUMENT
       # * gpnarray [Array (or 1D NArray) of GPhys]
       # 
-      def GPhys.join(gpary, ignore_overlap=false)
+      def GPhys.join(gpary, ignore_overlap=false, no_sort=false)
 
         #< initialization with the first GPhys object >
 
@@ -1332,7 +1333,7 @@ module NumRu
         gpnary = gpstore.to_na
 
         #< Sort along dimensions to join >
-        gpnary = __sort_gpnary(gpnary)
+        gpnary = __sort_gpnary(gpnary) unless no_sort
 
         #< Join! >
         self.join_md_nocheck(gpnary)
