@@ -463,7 +463,7 @@ module NumRu
       end
       if dir == @@fft_forward
 	if dims.length == 0
-	  fcoef = fcoef / fcoef.length       # normalized if forward FT
+	  fcoef = fcoef / fcoef.length.to_f   # normalized if forward FT
 	else
 	  sh = fcoef.shape
 	  len = 1
@@ -483,7 +483,7 @@ module NumRu
 	  cv = gfc.coord(i).val
 	  n = cv.length
 	  clen = (cv.max - cv.min) * n / (n-1)
-	  wn = (2*Math::PI/clen) * NArray.new(cv.typecode,cv.length).indgen!
+	  wn = (2*Math::PI/clen) * NArray.new(cv.typecode,cv.length).indgen!.to_f
 	  if (!backward)
 	    gfc.coord(i).set_att('origin_in_real_space',cv[0..0])
 	  else 
@@ -619,7 +619,7 @@ module NumRu
         if !factor
 	  factor = dwn**(-1)
 	else
-	  factor = factor / dwn
+	  factor = factor / dwn.to_f
 	end
       }
       self * factor
