@@ -80,17 +80,18 @@ module NumRu
           raise ArgumentError, "1st arg must be a GrADS_Gridded or a file name"
         end
 
-        grvar = file.var(varname)
+        grvar = GrADSVar.new(file,varname,true,false)
         data = VArrayGrADS.new(grvar)
 
-#        axposnames = [ "lon", "lat", "lev", "time" ]
-        axposnames = [ "x", "y", "z", "t" ]
-        rank = 4
+        shape_current = grvar.shape_current
+        dimnames = grvar.dim_names
+        rank = dimnames.length
         bare_index = [ false ] * rank # will be true if coord var is not found
 
         axes = Array.new
         for i in 0...rank
-          axpos = VArrayGrADS.new( file.var(axposnames[i]) )[0...data.shape_current[i]]
+          grvar = GrADSVar.new(file,dimnames[i],false,true)
+          axpos = VArrayGrADS.new(grvar)[0...shape_current[i]]
 
           cell_center = true
           cell = false
