@@ -276,10 +276,10 @@ module NumRu
           super
         end
       end
-      @@nc_pattern = [/\.nc$/]
-      @@grad_pattern = [/\.ctl$/]
-      @@grib_pattern = [/\.grib$/, /\.grb$/]
-      @@nus_pattern = [/\.nus$/]
+      @@nc_pattern = [/(\.nc|\.NC)$/]
+      @@grad_pattern = [/(\.ctl|\.CTL)$/]
+      @@grib_pattern = [/(\.grib|\.GRIB)$/, /(\.grb|\.GRB)$/]
+      @@nus_pattern = [/(\.nus|\.NUS)$/]
 
       @@has_he5 = defined?(HE5)
       if @@has_he5
