@@ -34,6 +34,9 @@ module NumRu
         unless NuSDaS === nusdas
           raise ArgumentError, "1st arg must be a NuSDaS of path name"
         end
+        unless (meta = nusdas.instance_variable_get(:@meta)) && meta[:nbasetime] && meta[:nbasetime] > 0
+          raise "NuSDaS directory is empty or nusdas_def is inconsistent with data: #{nusdas.path}"
+        end
 
         var = nusdas.var(varname)
         var.nil? && raise("#{varname} is not found")
