@@ -919,7 +919,7 @@ EOS
 
         imax, jmax = isize.to_i, jsize.to_i
         dx, dy = dx.to_f, dy.to_f
-        bi, bj = (iref.to_i)-1, (jref.to_i)-1
+        bi, bj = iref.to_f-1.0, jref.to_f-1.0
         by, bx = latref.to_f, lonref.to_f
         sy,sx = struelat.to_f, slon.to_f
         sy2, = ntruelat.to_f
@@ -932,8 +932,11 @@ EOS
         unless sx.abs < 180
           raise "parameter for standard is invalid"
         end
-        unless 0 < sy.abs && sy.abs < sy2.abs && sy2.abs < 90 && sy*sy2>0
-          raise "parameter for standard is invalid"
+        if sy.abs > 90
+          raise "Invalid PDEF (in control file): |struelat|>90"
+        end
+        if sy2.abs > 90
+          raise "Invalid PDEF (in control file): |ntruelat|>90"
         end
         bx = bx*PI/180
         by = by*PI/180
