@@ -611,12 +611,19 @@ class GPhys
       end
       alias :initial= :set_initial
       def date
-        d = Date.new((@pds.to_uint1(21)-1)*100 + @pds.to_uint1(9),
-                     @pds.to_uint1(10), @pds.to_uint1(11)
-                     )
-        h = [@pds.to_uint1(12), @pds.to_uint1(13)]
+        dt = DateTime.new((@pds.to_uint1(21)-1)*100 + @pds.to_uint1(9),
+                           @pds.to_uint1(10), @pds.to_uint1(11),
+                           @pds.to_uint1(12), @pds.to_uint1(13) )
+        dt += Units[time_unit].convert(p1,"day")  
+          # REMARK (horinouchi):
+          # Just to add p1 should be OK in the crudest sense,
+          # though one can further consider time_range
+          # (ref: http://rda.ucar.edu/docs/formats/grib/gribdoc/timer.html)
+        d = dt.to_date
+        h = [dt.hour, dt.min]
         return [d,h]
       end
+
       def time_unit
         return TIME_UNITS[ @pds.to_uint1(14) ]
       end
@@ -1238,11 +1245,15 @@ class GPhys
             #j = nil
             #i = nil
             if map
-              var = NArrayMiss.sfloat(index[0].count, index[1].count)
+              var = NArrayMiss.sfloat(nlon,nlat)
               map.reshape!(nlon,nlat)
-              mask = map[*index]
+              mask = map
               nd = mask.count_true
-              var[mask.where] = @sgm.mbio.read2D(@pos+8, nbits_pack, nd, 1, 0, nd-1, 1, 0, 0, 1, nil, nil, e, r).reshape!(nd)
+              wh = mask.where
+              if wh.length>0
+                var[wh] = @sgm.mbio.read2D(@pos+8, nbits_pack, nd, 1, 0, nd-1, 1, 0, 0, 1, nil, nil, e, r).reshape!(nd)
+              end
+              var = var[*index]
 =begin
               index[1].each{|j|
                 jj = j-index[1].first
