@@ -1,19 +1,20 @@
+# -*- coding: utf-8 -*-
 =begin
-= Gtool3 ` IO Cu[iƂĂ O () ͂Ȃj
+= Gtool3 形式 IO ライブラリー（といっても O (書き) はなし）
 
-== t@Ciiqt@Cjɂ
+== 軸ファイル（格子情報ファイル）について
 
-ϐ GTAXDIR ŁCt@Ĉ肩w肷邩,
-Gtool3.gtaxdir= \bhgĎw肷D
+環境変数 GTAXDIR で，軸ファイルのありかを指定するか,
+Gtool3.gtaxdir= メソッドを使って指定する．
 
-== Development Memo / J
+== Development Memo / 開発メモ
 
-iȏj̕ϐ̑ǧJԂ肷DāCwb_ǂ
-āCϐCT,U,PS,T,..ȂǂƓ̂ɖ߂C̎_ T,U,PS
-3ϐ̌JԂłƂ݂ȂD邱ƂŁCGrADS Ƃقړ悤
-悤ɂȂDȂCۂ Gtool3 t@Cׂ͂Ăł͂D
+複数（一個以上）の変数の組の繰り返しを仮定する．よって，ヘッダを読んで
+いって，変数名が，T,U,PS,T,..などと同じのに戻ったら，その時点で T,U,PS
+の3変数の繰り返しであるとみなす．こうすることで，GrADS とほぼ同じように
+扱えるようになる．なお，実際の Gtool3 ファイルはすべてこれでいけるはず．
 
-GfBA̓ubN؂肩玩ʂD
+エンディアンはブロック区切りから自動判別する．
 
 
 
@@ -414,7 +415,7 @@ module NumRu
           #p "*****",varinfo[:rlen]
           varinfo[:natyp] = NATYP[varinfo["DFMT"]]
           @varh[ varinfo["ITEM"] ] = varinfo
-          start_byte += skip_a_data_block(varinfo, @file)  # shapeƌ^̗pɂׂ
+          start_byte += skip_a_data_block(varinfo, @file)  # shapeと型の利用にかえるべき
         else
           time_seq = true    # second turn --> regarded as a time sequence
           break
@@ -724,48 +725,48 @@ if $0 == __FILE__
 end
 
 =begin
-    1     & IDFM   & I10   #& tH[}bgid  & 9009
-    2     & DSET   & A16   #& f[^Zbg  & AP01
-    3     & ITEM   & A16   #& ʖ(ϐ)& TMP
-    4     & EDIT1  & A16   #& ҏWL(1)   & TM1D
-    5     & EDIT2  & A16   #& ҏWL(2)   & XFK1
+    1     & IDFM   & I10   #& フォーマットid  & 9009
+    2     & DSET   & A16   #& データセット名  & AP01
+    3     & ITEM   & A16   #& 識別名称(変数名)& TMP
+    4     & EDIT1  & A16   #& 編集略記号(1)   & TM1D
+    5     & EDIT2  & A16   #& 編集略記号(2)   & XFK1
     ...
-    11    & EDIT8  & A16   #& ҏWL(8)   &  
-    12    & FNUM   & I10   #& t@Cԍ    & 1
-    13    & DNUM   & I10   #& f[^ԍ      & 100
-    14    & TITL1  & A16   #& ^Cg        & Temperature
-    15    & TITL2  & A16   #& \ \ V \ \  & 
-    16    & UNIT   & A16   #& P            & K
-    17    & ETTL1  & A16   #& ҏW^Cg(1) & Dayly mean
-    18    & ETTL2  & A16   #& ҏW^Cg(2) & filter (X)
+    11    & EDIT8  & A16   #& 編集略記号(8)   &  
+    12    & FNUM   & I10   #& ファイル番号    & 1
+    13    & DNUM   & I10   #& データ番号      & 100
+    14    & TITL1  & A16   #& タイトル        & Temperature
+    15    & TITL2  & A16   #& \ \ 〃 \ \ 続き & 
+    16    & UNIT   & A16   #& 単位            & K
+    17    & ETTL1  & A16   #& 編集タイトル(1) & Dayly mean
+    18    & ETTL2  & A16   #& 編集タイトル(2) & filter (X)
     ...
-    24    & ETTL8  & A16   #& ҏW^Cg(8) &          
-    25    & TIME   & I10   #& (ʂ)      & 18769650900
-    27    & UTIM   & A16   #& P        & SEC
-    26    & DATE   & A16   #& (yyyymmddhhmmss) & 19900813122800
-    28    & TDUR   & I10   #& f[^\  & 3600
-    29    & AITM1  & A16   #& 1̊iqʖ & GLON128
-    30    & ASTR1  & I10   #& 1̊iqԍn &   1
-    31    & AEND1  & I10   #& 1̊iqԍI & 128
-    32    & AITM2  & A16   #& 2̊iqʖ & GGLA64
-    33    & ASTR2  & I10   #& 2̊iqԍn &   1
-    34    & AEND2  & I10   #& 2̊iqԍI &  64
-    35    & AITM3  & A16   #& 3̊iqʖ & SIGA12
-    36    & ASTR3  & I10   #& 3̊iqԍn &   1
-    37    & AEND3  & I10   #& 3̊iqԍI &  12
-    38    & DFMT   & A16   #& f[^tH[}bg & (32F12.5) or UR4
-    39    & MISS   & E15.7 #& l̒l      & -9999.
-    40    & DMIN   & E15.7 #& W(ŏ)    & 100.  
-    41    & DMAX   & E15.7 #& W(ő)    & 300.  
-    42    & DIVS   & E15.7 #& Ԋu()        & 10.   
-    43    & DIVL   & E15.7 #& Ԋu()        & 50.   
-    44    & STYP   & I10   #& XP[O^Cv & 1  
-    45--47& OPTNx  & A16   #&             &
-    48--59& MEMOxx & A16   #&             &
-    60    & CDATE  & A16   #& f[^쐬t  & 19900813122800
-    61    & CSIGN  & A16   #& f[^쐬    & SWAMP     
-    62    & MDATE  & A16   #& f[^ύXt  & 19900926225422
-    63    & MSIGN  & A16   #& f[^ύX    & SWAMP     
-    64    & SIZE   & I10   #& z̃TCY    & 98304
+    24    & ETTL8  & A16   #& 編集タイトル(8) &          
+    25    & TIME   & I10   #& 時刻(通し)      & 18769650900
+    27    & UTIM   & A16   #& 時刻単位        & SEC
+    26    & DATE   & A16   #& 時刻(yyyymmddhhmmss) & 19900813122800
+    28    & TDUR   & I10   #& データ代表時間  & 3600
+    29    & AITM1  & A16   #& 軸1の格子識別名称 & GLON128
+    30    & ASTR1  & I10   #& 軸1の格子番号始め &   1
+    31    & AEND1  & I10   #& 軸1の格子番号終り & 128
+    32    & AITM2  & A16   #& 軸2の格子識別名称 & GGLA64
+    33    & ASTR2  & I10   #& 軸2の格子番号始め &   1
+    34    & AEND2  & I10   #& 軸2の格子番号終り &  64
+    35    & AITM3  & A16   #& 軸3の格子識別名称 & SIGA12
+    36    & ASTR3  & I10   #& 軸3の格子番号始め &   1
+    37    & AEND3  & I10   #& 軸3の格子番号終り &  12
+    38    & DFMT   & A16   #& データフォーマット & (32F12.5) or UR4
+    39    & MISS   & E15.7 #& 欠損値の値      & -9999.
+    40    & DMIN   & E15.7 #& レンジ(最小)    & 100.  
+    41    & DMAX   & E15.7 #& レンジ(最大)    & 300.  
+    42    & DIVS   & E15.7 #& 間隔(小)        & 10.   
+    43    & DIVL   & E15.7 #& 間隔(大)        & 50.   
+    44    & STYP   & I10   #& スケーリングタイプ & 1  
+    45--47& OPTNx  & A16   #& 空き            &
+    48--59& MEMOxx & A16   #& メモ            &
+    60    & CDATE  & A16   #& データ作成日付  & 19900813122800
+    61    & CSIGN  & A16   #& データ作成者    & SWAMP     
+    62    & MDATE  & A16   #& データ変更日付  & 19900926225422
+    63    & MSIGN  & A16   #& データ変更者    & SWAMP     
+    64    & SIZE   & I10   #& 配列のサイズ    & 98304
 
 =end
