@@ -394,7 +394,7 @@ module NumRu
 	else
 	  return [false, nil]
 	end
-      when Array
+      when Array, NArray
         match = false
         isb = []
         index.each{ |idx|
