@@ -158,6 +158,12 @@ module NumRu
 	     end
 	   }
 	    va = new( file.def_var(name, ntype, dimensions) )
+            if ( @@deflation_level &&
+                 ## file.respond_to?(:format) &&  # supported by ruby-netcdf 0.7.2 or later
+                 file.format >= NetCDF::NC_FORMAT_NETCDF4 &&
+                 (dimensions.length >=2 || @@deflate_all) )
+              file.var(name).deflate(@@deflation_level, @@shuffle)
+            end
             if vary
 	      vary.att_names.each{|name| va.set_att(name, vary.get_att(name))}
 	    end 
@@ -166,6 +172,38 @@ module NumRu
 
 	 alias def_var new2
 
+	 ## < NetCDF4 deflation (compression) settings for variable creation >
+
+         @@deflation_level = nil     # if integer, use deflation for NetCDF-4
+         def deflation_level=(level)
+           @@deflation_level = level   # Must be an integer from 0 to 9
+                                       # (usually 1 is good).
+                                       # Use 0 to use only the shuffle filter.
+         end
+         def deflation_level
+           @@deflation_level
+         end
+
+         @@deflate_all = false  # If false, @@deflation_level is applied to 
+                                # variables of 2D or with a greater rank.
+                                # If false, @@deflation_level is applied even
+                                # to 1D variables.
+         def deflate_all=(t_or_f)
+           @@deflate_all = t_or_f
+         end
+         def deflate_all
+           @@deflate_all
+         end
+
+         @@shuffle = false    # Use the shuffle filter for integer variables.
+                              # Effective only when deflation_level is non-nil.
+         def shuffle=(t_or_f)
+           @@shuffle = t_or_f
+         end
+         def shuffle
+           @@shuffle
+         end
+
 	 ## < additional class methods > ##
 
 	 def write(file, vary, rename=nil, dimnames=nil)
