@@ -1,13 +1,17 @@
-$LOAD_PATH.unshift("../lib/")
-require "numru/gphys/gphys.rb"
-require "numru/gphys/gphys_io.rb"
+require "numru/gphys/gphys"
+require "numru/gphys/gphys_io"
 require "test/unit"
 include NumRu
 
 class GPhysTest < Test::Unit::TestCase
   def setup
-    @T = GPhys::IO.open("../testdata/T.jan.nc","T")      # NetCDF data
-    @Tgd = GPhys::IO.open("../testdata/T.jan.ctl","T")   # GrADS data
+    begin
+      @T = GPhys::IO.open("testdata/T.jan.nc","T")      # NetCDF data
+      @Tgd = GPhys::IO.open("testdata/T.jan.ctl","T")   # GrADS data
+    rescue NetcdfSyserr
+      @T = GPhys::IO.open("../testdata/T.jan.nc","T")      # NetCDF data
+      @Tgd = GPhys::IO.open("../testdata/T.jan.ctl","T")   # GrADS data
+    end
   end
 
   def test_cyclic_ext
